package cn.iocoder.yudao.module.inspection.service;

import cn.iocoder.yudao.module.inspection.entity.DelInspectionInfo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import java.util.List;


/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2024-05-08
 */
public interface IDelInspectionInfoService
{
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public DelInspectionInfo selectDelInspectionInfoById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param delInspectionInfo 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public IPage<DelInspectionInfo> selectDelInspectionInfoList(Page<DelInspectionInfo> page, DelInspectionInfo delInspectionInfo);

    /**
     * 新增【请填写功能名称】
     *
     * @param delInspectionInfo 【请填写功能名称】
     * @return 结果
     */
    public int insertDelInspectionInfo(DelInspectionInfo delInspectionInfo);

    /**
     * 修改【请填写功能名称】
     *
     * @param delInspectionInfo 【请填写功能名称】
     * @return 结果
     */
    public int updateDelInspectionInfo(DelInspectionInfo delInspectionInfo);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteDelInspectionInfoByIds(Long[] ids);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteDelInspectionInfoById(Long id);
}
